# auto-meshroom

## Photogrammetry

Photogrammetry is the science of making measurements from photographs.
It infers the geometry of a scene from a set of unordered photographs or videos.
Photography is the projection of a 3D scene onto a 2D plane, losing depth information.
The goal of photogrammetry is to reverse this process.

first of all
------------

#### Hi there, I'm Shahaf Frank-Shapir

Just a bit about me...

- I just launched my complete python application for stock prediction, sentiment analysis and trading advisor!
- I’m currently learning biology, software engineering and systems engineering.
- I’m looking to collaborate with other content topics.
- 2021 Goals: Contribute more to privet projects.
- Fun fact: I love to draw and paint, sculpt, program (of course) play the piano and make origami.


before we start
---------------

### description:
- This program is a python wrapper for the Meshroom software.
- It provides a complete control of the 3D reconstruction process using python.
- The program provides object-oriented classes and methods to manage the process,
- that is being run through the command line, by the program itself. This means 
that all the hard configurations are left for the program to deal automatically, 
while you, the user, can build without limitations. 

### dependencies:
- opening:
  As for this is a really complex program, which uses a lot of modules, there are required dependencies needed
  in order to run the program. keep in mined the program was writen in python 3.8.6, so any python version lower
  than 3.8.1 might not work properly. Moreover, built-in python modules are being used, so keep that in mind.

- to install manually the required none-built-in python modules in command line:
  write in the project command line:
- install the dependencies manually by writing the following list to the command line in the project directory:
````
pip install -r requirements.txt
````